# coding: utf-8

"""
    Streams Api

    API that provides access to Moralis Streams  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_streams import schemas  # noqa: F401


class AptosStreamType(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "includeChanges",
            "functions",
            "description",
            "includePayload",
            "demo",
            "statusMessage",
            "webhookUrl",
            "network",
            "allAddresses",
            "id",
            "tag",
            "amountOfAddresses",
            "events",
            "includeEvents",
            "isErrorSince",
            "status",
        }
        
        class properties:
            id = schemas.StrSchema
            allAddresses = schemas.BoolSchema
            demo = schemas.BoolSchema
            description = schemas.StrSchema
            includeChanges = schemas.BoolSchema
            includeEvents = schemas.BoolSchema
            includePayload = schemas.BoolSchema
            
            
            class isErrorSince(
                schemas.DateTimeBase,
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                class MetaOapg:
                    format = 'date-time'
            
            
                def __new__(
                    cls,
                    *args: typing.Union[None, str, datetime, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'isErrorSince':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                    )
        
            @staticmethod
            def network() -> typing.Type['AptosNetwork']:
                return AptosNetwork
        
            @staticmethod
            def status() -> typing.Type['StreamsStatus']:
                return StreamsStatus
            statusMessage = schemas.StrSchema
            
            
            class events(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    items = schemas.StrSchema
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'events':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            
            
            class functions(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    items = schemas.StrSchema
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'functions':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            tag = schemas.StrSchema
            webhookUrl = schemas.StrSchema
            amountOfAddresses = schemas.Float64Schema
            __annotations__ = {
                "id": id,
                "allAddresses": allAddresses,
                "demo": demo,
                "description": description,
                "includeChanges": includeChanges,
                "includeEvents": includeEvents,
                "includePayload": includePayload,
                "isErrorSince": isErrorSince,
                "network": network,
                "status": status,
                "statusMessage": statusMessage,
                "events": events,
                "functions": functions,
                "tag": tag,
                "webhookUrl": webhookUrl,
                "amountOfAddresses": amountOfAddresses,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    includeChanges: MetaOapg.properties.includeChanges
    functions: MetaOapg.properties.functions
    description: MetaOapg.properties.description
    includePayload: MetaOapg.properties.includePayload
    demo: MetaOapg.properties.demo
    statusMessage: MetaOapg.properties.statusMessage
    webhookUrl: MetaOapg.properties.webhookUrl
    network: 'AptosNetwork'
    allAddresses: MetaOapg.properties.allAddresses
    id: MetaOapg.properties.id
    tag: MetaOapg.properties.tag
    amountOfAddresses: MetaOapg.properties.amountOfAddresses
    events: MetaOapg.properties.events
    includeEvents: MetaOapg.properties.includeEvents
    isErrorSince: MetaOapg.properties.isErrorSince
    status: 'StreamsStatus'
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["includeChanges"]) -> MetaOapg.properties.includeChanges: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["functions"]) -> MetaOapg.properties.functions: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["description"]) -> MetaOapg.properties.description: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["includePayload"]) -> MetaOapg.properties.includePayload: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["demo"]) -> MetaOapg.properties.demo: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["statusMessage"]) -> MetaOapg.properties.statusMessage: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["webhookUrl"]) -> MetaOapg.properties.webhookUrl: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["network"]) -> 'AptosNetwork': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["allAddresses"]) -> MetaOapg.properties.allAddresses: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["tag"]) -> MetaOapg.properties.tag: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["amountOfAddresses"]) -> MetaOapg.properties.amountOfAddresses: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["events"]) -> MetaOapg.properties.events: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["includeEvents"]) -> MetaOapg.properties.includeEvents: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["isErrorSince"]) -> MetaOapg.properties.isErrorSince: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["status"]) -> 'StreamsStatus': ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["includeChanges"], typing_extensions.Literal["functions"], typing_extensions.Literal["description"], typing_extensions.Literal["includePayload"], typing_extensions.Literal["demo"], typing_extensions.Literal["statusMessage"], typing_extensions.Literal["webhookUrl"], typing_extensions.Literal["network"], typing_extensions.Literal["allAddresses"], typing_extensions.Literal["id"], typing_extensions.Literal["tag"], typing_extensions.Literal["amountOfAddresses"], typing_extensions.Literal["events"], typing_extensions.Literal["includeEvents"], typing_extensions.Literal["isErrorSince"], typing_extensions.Literal["status"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["includeChanges"]) -> MetaOapg.properties.includeChanges: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["functions"]) -> MetaOapg.properties.functions: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["description"]) -> MetaOapg.properties.description: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["includePayload"]) -> MetaOapg.properties.includePayload: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["demo"]) -> MetaOapg.properties.demo: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["statusMessage"]) -> MetaOapg.properties.statusMessage: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["webhookUrl"]) -> MetaOapg.properties.webhookUrl: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["network"]) -> 'AptosNetwork': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["allAddresses"]) -> MetaOapg.properties.allAddresses: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["tag"]) -> MetaOapg.properties.tag: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["amountOfAddresses"]) -> MetaOapg.properties.amountOfAddresses: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["events"]) -> MetaOapg.properties.events: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["includeEvents"]) -> MetaOapg.properties.includeEvents: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["isErrorSince"]) -> MetaOapg.properties.isErrorSince: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["status"]) -> 'StreamsStatus': ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["includeChanges"], typing_extensions.Literal["functions"], typing_extensions.Literal["description"], typing_extensions.Literal["includePayload"], typing_extensions.Literal["demo"], typing_extensions.Literal["statusMessage"], typing_extensions.Literal["webhookUrl"], typing_extensions.Literal["network"], typing_extensions.Literal["allAddresses"], typing_extensions.Literal["id"], typing_extensions.Literal["tag"], typing_extensions.Literal["amountOfAddresses"], typing_extensions.Literal["events"], typing_extensions.Literal["includeEvents"], typing_extensions.Literal["isErrorSince"], typing_extensions.Literal["status"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        includeChanges: typing.Union[MetaOapg.properties.includeChanges, bool, ],
        functions: typing.Union[MetaOapg.properties.functions, list, tuple, ],
        description: typing.Union[MetaOapg.properties.description, str, ],
        includePayload: typing.Union[MetaOapg.properties.includePayload, bool, ],
        demo: typing.Union[MetaOapg.properties.demo, bool, ],
        statusMessage: typing.Union[MetaOapg.properties.statusMessage, str, ],
        webhookUrl: typing.Union[MetaOapg.properties.webhookUrl, str, ],
        network: 'AptosNetwork',
        allAddresses: typing.Union[MetaOapg.properties.allAddresses, bool, ],
        id: typing.Union[MetaOapg.properties.id, str, ],
        tag: typing.Union[MetaOapg.properties.tag, str, ],
        amountOfAddresses: typing.Union[MetaOapg.properties.amountOfAddresses, decimal.Decimal, int, float, ],
        events: typing.Union[MetaOapg.properties.events, list, tuple, ],
        includeEvents: typing.Union[MetaOapg.properties.includeEvents, bool, ],
        isErrorSince: typing.Union[MetaOapg.properties.isErrorSince, None, str, datetime, ],
        status: 'StreamsStatus',
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'AptosStreamType':
        return super().__new__(
            cls,
            *args,
            includeChanges=includeChanges,
            functions=functions,
            description=description,
            includePayload=includePayload,
            demo=demo,
            statusMessage=statusMessage,
            webhookUrl=webhookUrl,
            network=network,
            allAddresses=allAddresses,
            id=id,
            tag=tag,
            amountOfAddresses=amountOfAddresses,
            events=events,
            includeEvents=includeEvents,
            isErrorSince=isErrorSince,
            status=status,
            _configuration=_configuration,
        )

from openapi_streams.model.aptos_network import AptosNetwork
from openapi_streams.model.streams_status import StreamsStatus



# coding: utf-8

"""
    Streams Api

    API that provides access to Moralis Streams  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_streams import schemas  # noqa: F401


class AptosCoinTransfer(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "valueWithDecimals",
            "from",
            "to",
            "value",
            "transaction",
            "coin",
        }
        
        class properties:
            transaction = schemas.StrSchema
            valueWithDecimals = schemas.Float64Schema
            _from = schemas.StrSchema
            value = schemas.StrSchema
            to = schemas.StrSchema
        
            @staticmethod
            def coin() -> typing.Type['AptosCoin']:
                return AptosCoin
            __annotations__ = {
                "transaction": transaction,
                "valueWithDecimals": valueWithDecimals,
                "from": _from,
                "value": value,
                "to": to,
                "coin": coin,
            }
    
    valueWithDecimals: MetaOapg.properties.valueWithDecimals
    to: MetaOapg.properties.to
    value: MetaOapg.properties.value
    transaction: MetaOapg.properties.transaction
    coin: 'AptosCoin'
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["transaction"]) -> MetaOapg.properties.transaction: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["valueWithDecimals"]) -> MetaOapg.properties.valueWithDecimals: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["from"]) -> MetaOapg.properties._from: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["value"]) -> MetaOapg.properties.value: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["to"]) -> MetaOapg.properties.to: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["coin"]) -> 'AptosCoin': ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["transaction", "valueWithDecimals", "from", "value", "to", "coin", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["transaction"]) -> MetaOapg.properties.transaction: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["valueWithDecimals"]) -> MetaOapg.properties.valueWithDecimals: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["from"]) -> MetaOapg.properties._from: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["value"]) -> MetaOapg.properties.value: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["to"]) -> MetaOapg.properties.to: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["coin"]) -> 'AptosCoin': ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["transaction", "valueWithDecimals", "from", "value", "to", "coin", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        valueWithDecimals: typing.Union[MetaOapg.properties.valueWithDecimals, decimal.Decimal, int, float, ],
        to: typing.Union[MetaOapg.properties.to, str, ],
        value: typing.Union[MetaOapg.properties.value, str, ],
        transaction: typing.Union[MetaOapg.properties.transaction, str, ],
        coin: 'AptosCoin',
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'AptosCoinTransfer':
        return super().__new__(
            cls,
            *args,
            valueWithDecimals=valueWithDecimals,
            to=to,
            value=value,
            transaction=transaction,
            coin=coin,
            _configuration=_configuration,
            **kwargs,
        )

from openapi_streams.model.aptos_coin import AptosCoin



import json
import typing
import typing_extensions
from .api_instance import get_api_instance
from openapi_evm_api.paths.erc20_transfers.get import RequestQueryParams



class QueryParams(RequestQueryParams):
    pass

class Params(QueryParams,):
    pass

def get_erc20_transfers(api_key: str, params: Params):
    api_instance = get_api_instance(api_key, params)
    query_params: typing.Any = {k: v for k, v in params.items() if k in RequestQueryParams.__annotations__.keys()}
    api_response = api_instance.get_erc20_transfers(
        query_params=query_params,
        accept_content_types=(
            'application/json; charset=utf-8',
        ),
        skip_deserialization=True
    )

    return json.loads(api_response.response.data)



# coding: utf-8

"""
    EVM API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.1
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_evm_api import schemas  # noqa: F401


class InternalTransaction(
    schemas.AnyTypeSchema,
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "output",
            "input",
            "gas_used",
            "gas",
            "block_hash",
            "block_number",
            "from",
            "to",
            "type",
            "value",
            "transaction_hash",
        }
        
        class properties:
            transaction_hash = schemas.StrSchema
            block_number = schemas.StrSchema
            block_hash = schemas.StrSchema
            type = schemas.StrSchema
            _from = schemas.StrSchema
            to = schemas.StrSchema
            value = schemas.StrSchema
            gas = schemas.StrSchema
            gas_used = schemas.StrSchema
            input = schemas.StrSchema
            output = schemas.StrSchema
            __annotations__ = {
                "transaction_hash": transaction_hash,
                "block_number": block_number,
                "block_hash": block_hash,
                "type": type,
                "from": _from,
                "to": to,
                "value": value,
                "gas": gas,
                "gas_used": gas_used,
                "input": input,
                "output": output,
            }

    
    output: MetaOapg.properties.output
    input: MetaOapg.properties.input
    gas_used: MetaOapg.properties.gas_used
    gas: MetaOapg.properties.gas
    block_hash: MetaOapg.properties.block_hash
    block_number: MetaOapg.properties.block_number
    to: MetaOapg.properties.to
    type: MetaOapg.properties.type
    value: MetaOapg.properties.value
    transaction_hash: MetaOapg.properties.transaction_hash
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["transaction_hash"]) -> MetaOapg.properties.transaction_hash: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["block_number"]) -> MetaOapg.properties.block_number: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["block_hash"]) -> MetaOapg.properties.block_hash: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["from"]) -> MetaOapg.properties._from: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["to"]) -> MetaOapg.properties.to: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["value"]) -> MetaOapg.properties.value: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["gas"]) -> MetaOapg.properties.gas: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["gas_used"]) -> MetaOapg.properties.gas_used: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["input"]) -> MetaOapg.properties.input: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["output"]) -> MetaOapg.properties.output: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["transaction_hash", "block_number", "block_hash", "type", "from", "to", "value", "gas", "gas_used", "input", "output", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["transaction_hash"]) -> MetaOapg.properties.transaction_hash: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["block_number"]) -> MetaOapg.properties.block_number: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["block_hash"]) -> MetaOapg.properties.block_hash: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["from"]) -> MetaOapg.properties._from: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["to"]) -> MetaOapg.properties.to: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["value"]) -> MetaOapg.properties.value: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["gas"]) -> MetaOapg.properties.gas: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["gas_used"]) -> MetaOapg.properties.gas_used: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["input"]) -> MetaOapg.properties.input: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["output"]) -> MetaOapg.properties.output: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["transaction_hash", "block_number", "block_hash", "type", "from", "to", "value", "gas", "gas_used", "input", "output", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
        output: typing.Union[MetaOapg.properties.output, str, ],
        input: typing.Union[MetaOapg.properties.input, str, ],
        gas_used: typing.Union[MetaOapg.properties.gas_used, str, ],
        gas: typing.Union[MetaOapg.properties.gas, str, ],
        block_hash: typing.Union[MetaOapg.properties.block_hash, str, ],
        block_number: typing.Union[MetaOapg.properties.block_number, str, ],
        to: typing.Union[MetaOapg.properties.to, str, ],
        type: typing.Union[MetaOapg.properties.type, str, ],
        value: typing.Union[MetaOapg.properties.value, str, ],
        transaction_hash: typing.Union[MetaOapg.properties.transaction_hash, str, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'InternalTransaction':
        return super().__new__(
            cls,
            *args,
            output=output,
            input=input,
            gas_used=gas_used,
            gas=gas,
            block_hash=block_hash,
            block_number=block_number,
            to=to,
            type=type,
            value=value,
            transaction_hash=transaction_hash,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    aptos-api

    The aptos-api provider  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_aptos_api import schemas  # noqa: F401


class GetCoinTransfersByBlockHeightsResponse(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "cursor",
            "result",
            "hasNextPage",
        }
        
        class properties:
            
            
            class cursor(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                def __new__(
                    cls,
                    *args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'cursor':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                    )
            hasNextPage = schemas.BoolSchema
            
            
            class result(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    max_items = 100
                    min_items = 0
                    
                    @staticmethod
                    def items() -> typing.Type['CoinTransferDto']:
                        return CoinTransferDto
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple['CoinTransferDto'], typing.List['CoinTransferDto']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'result':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'CoinTransferDto':
                    return super().__getitem__(i)
            __annotations__ = {
                "cursor": cursor,
                "hasNextPage": hasNextPage,
                "result": result,
            }
    
    cursor: MetaOapg.properties.cursor
    result: MetaOapg.properties.result
    hasNextPage: MetaOapg.properties.hasNextPage
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["cursor"]) -> MetaOapg.properties.cursor: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["hasNextPage"]) -> MetaOapg.properties.hasNextPage: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["result"]) -> MetaOapg.properties.result: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["cursor", "hasNextPage", "result", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["cursor"]) -> MetaOapg.properties.cursor: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["hasNextPage"]) -> MetaOapg.properties.hasNextPage: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["result"]) -> MetaOapg.properties.result: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["cursor", "hasNextPage", "result", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        cursor: typing.Union[MetaOapg.properties.cursor, None, str, ],
        result: typing.Union[MetaOapg.properties.result, list, tuple, ],
        hasNextPage: typing.Union[MetaOapg.properties.hasNextPage, bool, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'GetCoinTransfersByBlockHeightsResponse':
        return super().__new__(
            cls,
            *args,
            cursor=cursor,
            result=result,
            hasNextPage=hasNextPage,
            _configuration=_configuration,
            **kwargs,
        )

from openapi_aptos_api.model.coin_transfer_dto import CoinTransferDto



from .get_contract_nfts import get_contract_nfts
from .get_multiple_nfts import get_multiple_nfts
from .get_nft_contract_metadata import get_nft_contract_metadata
from .get_nft_contract_transfers import get_nft_contract_transfers
from .get_nft_lowest_price import get_nft_lowest_price
from .get_nft_metadata import get_nft_metadata
from .get_nft_owners import get_nft_owners
from .get_nft_token_id_owners import get_nft_token_id_owners
from .get_nft_trades import get_nft_trades
from .get_nft_transfers import get_nft_transfers
from .get_nft_transfers_by_block import get_nft_transfers_by_block
from .get_nft_transfers_from_to_block import get_nft_transfers_from_to_block
from .get_wallet_nft_collections import get_wallet_nft_collections
from .get_wallet_nft_transfers import get_wallet_nft_transfers
from .get_wallet_nfts import get_wallet_nfts
from .re_sync_metadata import re_sync_metadata
from .search_nfts import search_nfts
from .sync_nft_contract import sync_nft_contract



# coding: utf-8

"""
    Streams Api

    API that provides access to Moralis Streams  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from openapi_streams.paths.streams_evm_id_address.post import AddAddressToStream
from openapi_streams.paths.streams_evm.put import CreateStream
from openapi_streams.paths.streams_evm_id_address.delete import DeleteAddressFromStream
from openapi_streams.paths.streams_evm_id.delete import DeleteStream
from openapi_streams.paths.streams_evm_id_address.get import GetAddresses
from openapi_streams.paths.streams_evm_id.get import GetStream
from openapi_streams.paths.streams_evm.get import GetStreams
from openapi_streams.paths.streams_evm_id.post import UpdateStream
from openapi_streams.paths.streams_evm_id_status.post import UpdateStreamStatus


class EvmStreamsApi(
    AddAddressToStream,
    CreateStream,
    DeleteAddressFromStream,
    DeleteStream,
    GetAddresses,
    GetStream,
    GetStreams,
    UpdateStream,
    UpdateStreamStatus,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    EVM API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.1
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_evm_api import schemas  # noqa: F401


class NativeBalances(
    schemas.ListSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        
        
        class items(
            schemas.DictSchema
        ):
        
        
            class MetaOapg:
                required = {
                    "total_balance",
                    "wallet_balances",
                    "chain",
                    "chain_id",
                    "block_timestamp",
                    "block_number",
                    "total_balance_formatted",
                }
                
                class properties:
                    chain = schemas.StrSchema
                    chain_id = schemas.StrSchema
                    total_balance = schemas.StrSchema
                    block_number = schemas.StrSchema
                    block_timestamp = schemas.StrSchema
                    total_balance_formatted = schemas.StrSchema
                    
                    
                    class wallet_balances(
                        schemas.ListSchema
                    ):
                    
                    
                        class MetaOapg:
                            
                            
                            class items(
                                schemas.DictSchema
                            ):
                            
                            
                                class MetaOapg:
                                    required = {
                                        "address",
                                        "balance",
                                        "balance_formatted",
                                    }
                                    
                                    class properties:
                                        address = schemas.StrSchema
                                        balance = schemas.StrSchema
                                        balance_formatted = schemas.StrSchema
                                        __annotations__ = {
                                            "address": address,
                                            "balance": balance,
                                            "balance_formatted": balance_formatted,
                                        }
                                
                                address: MetaOapg.properties.address
                                balance: MetaOapg.properties.balance
                                balance_formatted: MetaOapg.properties.balance_formatted
                                
                                @typing.overload
                                def __getitem__(self, name: typing_extensions.Literal["address"]) -> MetaOapg.properties.address: ...
                                
                                @typing.overload
                                def __getitem__(self, name: typing_extensions.Literal["balance"]) -> MetaOapg.properties.balance: ...
                                
                                @typing.overload
                                def __getitem__(self, name: typing_extensions.Literal["balance_formatted"]) -> MetaOapg.properties.balance_formatted: ...
                                
                                @typing.overload
                                def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                                
                                def __getitem__(self, name: typing.Union[typing_extensions.Literal["address", "balance", "balance_formatted", ], str]):
                                    # dict_instance[name] accessor
                                    return super().__getitem__(name)
                                
                                
                                @typing.overload
                                def get_item_oapg(self, name: typing_extensions.Literal["address"]) -> MetaOapg.properties.address: ...
                                
                                @typing.overload
                                def get_item_oapg(self, name: typing_extensions.Literal["balance"]) -> MetaOapg.properties.balance: ...
                                
                                @typing.overload
                                def get_item_oapg(self, name: typing_extensions.Literal["balance_formatted"]) -> MetaOapg.properties.balance_formatted: ...
                                
                                @typing.overload
                                def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                                
                                def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["address", "balance", "balance_formatted", ], str]):
                                    return super().get_item_oapg(name)
                                
                            
                                def __new__(
                                    cls,
                                    *args: typing.Union[dict, frozendict.frozendict, ],
                                    address: typing.Union[MetaOapg.properties.address, str, ],
                                    balance: typing.Union[MetaOapg.properties.balance, str, ],
                                    balance_formatted: typing.Union[MetaOapg.properties.balance_formatted, str, ],
                                    _configuration: typing.Optional[schemas.Configuration] = None,
                                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                                ) -> 'items':
                                    return super().__new__(
                                        cls,
                                        *args,
                                        address=address,
                                        balance=balance,
                                        balance_formatted=balance_formatted,
                                        _configuration=_configuration,
                                        **kwargs,
                                    )
                    
                        def __new__(
                            cls,
                            arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, dict, frozendict.frozendict, ]], typing.List[typing.Union[MetaOapg.items, dict, frozendict.frozendict, ]]],
                            _configuration: typing.Optional[schemas.Configuration] = None,
                        ) -> 'wallet_balances':
                            return super().__new__(
                                cls,
                                arg,
                                _configuration=_configuration,
                            )
                    
                        def __getitem__(self, i: int) -> MetaOapg.items:
                            return super().__getitem__(i)
                    __annotations__ = {
                        "chain": chain,
                        "chain_id": chain_id,
                        "total_balance": total_balance,
                        "block_number": block_number,
                        "block_timestamp": block_timestamp,
                        "total_balance_formatted": total_balance_formatted,
                        "wallet_balances": wallet_balances,
                    }
            
            total_balance: MetaOapg.properties.total_balance
            wallet_balances: MetaOapg.properties.wallet_balances
            chain: MetaOapg.properties.chain
            chain_id: MetaOapg.properties.chain_id
            block_timestamp: MetaOapg.properties.block_timestamp
            block_number: MetaOapg.properties.block_number
            total_balance_formatted: MetaOapg.properties.total_balance_formatted
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["chain"]) -> MetaOapg.properties.chain: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["chain_id"]) -> MetaOapg.properties.chain_id: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["total_balance"]) -> MetaOapg.properties.total_balance: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["block_number"]) -> MetaOapg.properties.block_number: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["block_timestamp"]) -> MetaOapg.properties.block_timestamp: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["total_balance_formatted"]) -> MetaOapg.properties.total_balance_formatted: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["wallet_balances"]) -> MetaOapg.properties.wallet_balances: ...
            
            @typing.overload
            def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
            
            def __getitem__(self, name: typing.Union[typing_extensions.Literal["chain", "chain_id", "total_balance", "block_number", "block_timestamp", "total_balance_formatted", "wallet_balances", ], str]):
                # dict_instance[name] accessor
                return super().__getitem__(name)
            
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["chain"]) -> MetaOapg.properties.chain: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["chain_id"]) -> MetaOapg.properties.chain_id: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["total_balance"]) -> MetaOapg.properties.total_balance: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["block_number"]) -> MetaOapg.properties.block_number: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["block_timestamp"]) -> MetaOapg.properties.block_timestamp: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["total_balance_formatted"]) -> MetaOapg.properties.total_balance_formatted: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["wallet_balances"]) -> MetaOapg.properties.wallet_balances: ...
            
            @typing.overload
            def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
            
            def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["chain", "chain_id", "total_balance", "block_number", "block_timestamp", "total_balance_formatted", "wallet_balances", ], str]):
                return super().get_item_oapg(name)
            
        
            def __new__(
                cls,
                *args: typing.Union[dict, frozendict.frozendict, ],
                total_balance: typing.Union[MetaOapg.properties.total_balance, str, ],
                wallet_balances: typing.Union[MetaOapg.properties.wallet_balances, list, tuple, ],
                chain: typing.Union[MetaOapg.properties.chain, str, ],
                chain_id: typing.Union[MetaOapg.properties.chain_id, str, ],
                block_timestamp: typing.Union[MetaOapg.properties.block_timestamp, str, ],
                block_number: typing.Union[MetaOapg.properties.block_number, str, ],
                total_balance_formatted: typing.Union[MetaOapg.properties.total_balance_formatted, str, ],
                _configuration: typing.Optional[schemas.Configuration] = None,
                **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
            ) -> 'items':
                return super().__new__(
                    cls,
                    *args,
                    total_balance=total_balance,
                    wallet_balances=wallet_balances,
                    chain=chain,
                    chain_id=chain_id,
                    block_timestamp=block_timestamp,
                    block_number=block_number,
                    total_balance_formatted=total_balance_formatted,
                    _configuration=_configuration,
                    **kwargs,
                )

    def __new__(
        cls,
        arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, dict, frozendict.frozendict, ]], typing.List[typing.Union[MetaOapg.items, dict, frozendict.frozendict, ]]],
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'NativeBalances':
        return super().__new__(
            cls,
            arg,
            _configuration=_configuration,
        )

    def __getitem__(self, i: int) -> MetaOapg.items:
        return super().__getitem__(i)



# coding: utf-8

"""


    Generated by: https://openapi-generator.tech
"""

from dataclasses import dataclass
import typing_extensions
import urllib3
from urllib3._collections import HTTPHeaderDict

from openapi_streams import api_client, exceptions
from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_streams import schemas  # noqa: F401

from openapi_streams.model.streams_types_uuid import StreamsTypesUUID

from . import path

# Query params
LimitSchema = schemas.Float64Schema
CursorSchema = schemas.StrSchema
RequestRequiredQueryParams = typing_extensions.TypedDict(
    'RequestRequiredQueryParams',
    {
        'limit': typing.Union[LimitSchema, decimal.Decimal, int, float, ],
    }
)
RequestOptionalQueryParams = typing_extensions.TypedDict(
    'RequestOptionalQueryParams',
    {
        'cursor': typing.Union[CursorSchema, str, ],
    },
    total=False
)


class RequestQueryParams(RequestRequiredQueryParams, RequestOptionalQueryParams):
    pass


request_query_limit = api_client.QueryParameter(
    name="limit",
    style=api_client.ParameterStyle.FORM,
    schema=LimitSchema,
    required=True,
    explode=True,
)
request_query_cursor = api_client.QueryParameter(
    name="cursor",
    style=api_client.ParameterStyle.FORM,
    schema=CursorSchema,
    explode=True,
)
# Path params
IdSchema = StreamsTypesUUID
RequestRequiredPathParams = typing_extensions.TypedDict(
    'RequestRequiredPathParams',
    {
        'id': typing.Union[IdSchema, ],
    }
)
RequestOptionalPathParams = typing_extensions.TypedDict(
    'RequestOptionalPathParams',
    {
    },
    total=False
)


class RequestPathParams(RequestRequiredPathParams, RequestOptionalPathParams):
    pass


request_path_id = api_client.PathParameter(
    name="id",
    style=api_client.ParameterStyle.SIMPLE,
    schema=IdSchema,
    required=True,
)
_auth = [
    'x-api-key',
]


class SchemaFor200ResponseBodyApplicationJson(
    schemas.DictSchema
):


    class MetaOapg:
        required = {
            "result",
            "total",
        }
        
        class properties:
            cursor = schemas.StrSchema
            total = schemas.Float64Schema
            
            
            class result(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    
                    class items(
                        schemas.DictSchema
                    ):
                    
                    
                        class MetaOapg:
                            required = {
                                "address",
                            }
                            
                            class properties:
                                
                                
                                class address(
                                    schemas.ComposedSchema,
                                ):
                                
                                
                                    class MetaOapg:
                                        any_of_0 = schemas.StrSchema
                                        
                                        
                                        class any_of_1(
                                            schemas.ListSchema
                                        ):
                                        
                                        
                                            class MetaOapg:
                                                items = schemas.StrSchema
                                        
                                            def __new__(
                                                cls,
                                                arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                                                _configuration: typing.Optional[schemas.Configuration] = None,
                                            ) -> 'any_of_1':
                                                return super().__new__(
                                                    cls,
                                                    arg,
                                                    _configuration=_configuration,
                                                )
                                        
                                            def __getitem__(self, i: int) -> MetaOapg.items:
                                                return super().__getitem__(i)
                                        
                                        @classmethod
                                        @functools.lru_cache()
                                        def any_of(cls):
                                            # we need this here to make our import statements work
                                            # we must store _composed_schemas in here so the code is only run
                                            # when we invoke this method. If we kept this at the class
                                            # level we would get an error because the class level
                                            # code would be run when this module is imported, and these composed
                                            # classes don't exist yet because their module has not finished
                                            # loading
                                            return [
                                                cls.any_of_0,
                                                cls.any_of_1,
                                            ]
                                
                                
                                    def __new__(
                                        cls,
                                        *args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                                        _configuration: typing.Optional[schemas.Configuration] = None,
                                        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                                    ) -> 'address':
                                        return super().__new__(
                                            cls,
                                            *args,
                                            _configuration=_configuration,
                                            **kwargs,
                                        )
                                __annotations__ = {
                                    "address": address,
                                }
                        
                        address: MetaOapg.properties.address
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["address"]) -> MetaOapg.properties.address: ...
                        
                        @typing.overload
                        def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                        
                        def __getitem__(self, name: typing.Union[typing_extensions.Literal["address", ], str]):
                            # dict_instance[name] accessor
                            return super().__getitem__(name)
                        
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["address"]) -> MetaOapg.properties.address: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                        
                        def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["address", ], str]):
                            return super().get_item_oapg(name)
                        
                    
                        def __new__(
                            cls,
                            *args: typing.Union[dict, frozendict.frozendict, ],
                            address: typing.Union[MetaOapg.properties.address, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                            _configuration: typing.Optional[schemas.Configuration] = None,
                            **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                        ) -> 'items':
                            return super().__new__(
                                cls,
                                *args,
                                address=address,
                                _configuration=_configuration,
                                **kwargs,
                            )
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, dict, frozendict.frozendict, ]], typing.List[typing.Union[MetaOapg.items, dict, frozendict.frozendict, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'result':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            __annotations__ = {
                "cursor": cursor,
                "total": total,
                "result": result,
            }
    
    result: MetaOapg.properties.result
    total: MetaOapg.properties.total
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["cursor"]) -> MetaOapg.properties.cursor: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["total"]) -> MetaOapg.properties.total: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["result"]) -> MetaOapg.properties.result: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["cursor", "total", "result", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["cursor"]) -> typing.Union[MetaOapg.properties.cursor, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["total"]) -> MetaOapg.properties.total: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["result"]) -> MetaOapg.properties.result: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["cursor", "total", "result", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        result: typing.Union[MetaOapg.properties.result, list, tuple, ],
        total: typing.Union[MetaOapg.properties.total, decimal.Decimal, int, float, ],
        cursor: typing.Union[MetaOapg.properties.cursor, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'SchemaFor200ResponseBodyApplicationJson':
        return super().__new__(
            cls,
            *args,
            result=result,
            total=total,
            cursor=cursor,
            _configuration=_configuration,
            **kwargs,
        )


@dataclass
class ApiResponseFor200(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor200ResponseBodyApplicationJson,
    ]
    headers: schemas.Unset = schemas.unset


_response_for_200 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor200,
    content={
        'application/json': api_client.MediaType(
            schema=SchemaFor200ResponseBodyApplicationJson),
    },
)
_status_code_to_response = {
    '200': _response_for_200,
}
_all_accept_content_types = (
    'application/json',
)


class BaseApi(api_client.Api):
    @typing.overload
    def _aptos_streams_get_addresses_oapg(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor200,
    ]: ...

    @typing.overload
    def _aptos_streams_get_addresses_oapg(
        self,
        skip_deserialization: typing_extensions.Literal[True],
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> api_client.ApiResponseWithoutDeserialization: ...

    @typing.overload
    def _aptos_streams_get_addresses_oapg(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = ...,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization,
    ]: ...

    def _aptos_streams_get_addresses_oapg(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ):
        """
        Get addresses by aptos stream id
        :param skip_deserialization: If true then api_response.response will be set but
            api_response.body and api_response.headers will not be deserialized into schema
            class instances
        """
        self._verify_typed_dict_inputs_oapg(RequestQueryParams, query_params)
        self._verify_typed_dict_inputs_oapg(RequestPathParams, path_params)
        used_path = path.value

        _path_params = {}
        for parameter in (
            request_path_id,
        ):
            parameter_data = path_params.get(parameter.name, schemas.unset)
            if parameter_data is schemas.unset:
                continue
            serialized_data = parameter.serialize(parameter_data)
            _path_params.update(serialized_data)

        for k, v in _path_params.items():
            used_path = used_path.replace('{%s}' % k, v)

        prefix_separator_iterator = None
        for parameter in (
            request_query_limit,
            request_query_cursor,
        ):
            parameter_data = query_params.get(parameter.name, schemas.unset)
            if parameter_data is schemas.unset:
                continue
            if prefix_separator_iterator is None:
                prefix_separator_iterator = parameter.get_prefix_separator_iterator()
            serialized_data = parameter.serialize(parameter_data, prefix_separator_iterator)
            for serialized_value in serialized_data.values():
                used_path += serialized_value

        _headers = HTTPHeaderDict()
        # TODO add cookie handling
        if accept_content_types:
            for accept_content_type in accept_content_types:
                _headers.add('Accept', accept_content_type)

        response = self.api_client.call_api(
            resource_path=used_path,
            method='get'.upper(),
            headers=_headers,
            auth_settings=_auth,
            stream=stream,
            timeout=timeout,
        )

        if skip_deserialization:
            api_response = api_client.ApiResponseWithoutDeserialization(response=response)
        else:
            response_for_status = _status_code_to_response.get(str(response.status))
            if response_for_status:
                api_response = response_for_status.deserialize(response, self.api_client.configuration)
            else:
                api_response = api_client.ApiResponseWithoutDeserialization(response=response)

        if not 200 <= response.status <= 299:
            raise exceptions.ApiException(api_response=api_response)

        return api_response


class AptosStreamsGetAddresses(BaseApi):
    # this class is used by api classes that refer to endpoints with operationId fn names

    @typing.overload
    def aptos_streams_get_addresses(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor200,
    ]: ...

    @typing.overload
    def aptos_streams_get_addresses(
        self,
        skip_deserialization: typing_extensions.Literal[True],
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> api_client.ApiResponseWithoutDeserialization: ...

    @typing.overload
    def aptos_streams_get_addresses(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = ...,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization,
    ]: ...

    def aptos_streams_get_addresses(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ):
        return self._aptos_streams_get_addresses_oapg(
            query_params=query_params,
            path_params=path_params,
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )


class ApiForget(BaseApi):
    # this class is used by api classes that refer to endpoints by path and http method names

    @typing.overload
    def get(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor200,
    ]: ...

    @typing.overload
    def get(
        self,
        skip_deserialization: typing_extensions.Literal[True],
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> api_client.ApiResponseWithoutDeserialization: ...

    @typing.overload
    def get(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = ...,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization,
    ]: ...

    def get(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ):
        return self._aptos_streams_get_addresses_oapg(
            query_params=query_params,
            path_params=path_params,
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )


